‫در این پروژه با یک مدل query2vec ساخته ایم. این مدل، از یک پیکره متنی مدل word2vec را آموزش میدهد و همچنین idf کلمات را استخراج میکند.
‫سپس با استفاده از خروجی مدل word2vec و استفاده از idf کلمات به عنوان وزنها، برای کوئری یک بردار میسازیم.

